@@ -6,7 +6,6 @@ use strict;
 use warnings;
 
 use Carp;
-use POSIX qw{ uname };
 
 sub new {
     my ( $class ) = @_;
@@ -21,26 +20,11 @@ sub new {
 sub build_requires {
     my ( $self, @extra ) = @_;
     return +{
-	'Test::More'	=> 0.96,	# Because of subtest().
+	'Test::More'	=> 0.88,	# Because of done_testing().
 	@extra,
     };
 }
 
-sub ccflags {
-    my @ccflags;
-    my ( $darwin_version ) = split qr{ [.] }smx, ( uname() )[2];
-    $darwin_version >= 8
-	and push @ccflags, '-DTIGER';
-    -f '/usr/include/MacTypes.h'
-	and push @ccflags, '-DUSE_MACTYPES';
-    if ( my $debug = $ENV{DEVELOPER_DEBUG} ) {
-	push @ccflags, '-DDEBUG_PBL';
-	$debug =~ m/ \b backtrace \b /smxi
-	    and push @ccflags, '-DDEBUG_PBL_BACKTRACE';
-    }
-    return @ccflags;
-}
-
 sub distribution {
     my ( $self ) = @_;
     return $self->{distribution};
@@ -52,7 +36,6 @@ sub requires {
 ##  }
     return {
 	'Carp'		=> 0,
-	'Encode'	=> 0,
 	'Scalar::Util'	=> 1.01,
 	'strict'	=> 0,
 	'warnings'	=> 0,
@@ -108,14 +91,6 @@ modules required to build the C<PPIx::Regexp> package, suitable for
 use in a F<Build.PL> C<build_requires> key, or a F<Makefile.PL>
 C<< {META_MERGE}->{build_requires} >> or C<BUILD_REQUIRES> key.
 
-=head2 ccflags
-
- my @ccflags = $meta->ccflags();
- print "cc flags - @ccflags\n";
-
-This method computes and returns the flags to be passed to the C
-compiler.
-
 =head2 distribution
 
  if ( $meta->distribution() ) {
@@ -171,7 +146,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2014 by Thomas R. Wyant, III
+Copyright (C) 2010-2012 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
